@@ -1,6 +1,6 @@
 DATA = {
   "Examples": [], 
-  "dist": "python-qosf-1.1.7-py_0", 
+  "dist": "python-qosf-1.1.8-py_0", 
   "python-scripts": [], 
   "site-packages": [
     "QOpenScienceFramework/__init__.py", 
@@ -19,30 +19,12 @@ DATA = {
     "QOpenScienceFramework/widgets/osfexplorer.py", 
     "QOpenScienceFramework/widgets/projecttree.py", 
     "QOpenScienceFramework/widgets/userbadge.py", 
-    "humanize-0.5.1-py2.7.egg-info/PKG-INFO", 
-    "humanize-0.5.1-py2.7.egg-info/SOURCES.txt", 
-    "humanize-0.5.1-py2.7.egg-info/dependency_links.txt", 
-    "humanize-0.5.1-py2.7.egg-info/entry_points.txt", 
-    "humanize-0.5.1-py2.7.egg-info/not-zip-safe", 
-    "humanize-0.5.1-py2.7.egg-info/top_level.txt", 
-    "humanize/__init__.py", 
-    "humanize/compat.py", 
-    "humanize/filesize.py", 
-    "humanize/i18n.py", 
-    "humanize/locale/fr_FR/LC_MESSAGES/humanize.mo", 
-    "humanize/locale/fr_FR/LC_MESSAGES/humanize.po", 
-    "humanize/locale/ko_KR/LC_MESSAGES/humanize.mo", 
-    "humanize/locale/ko_KR/LC_MESSAGES/humanize.po", 
-    "humanize/locale/ru_RU/LC_MESSAGES/humanize.mo", 
-    "humanize/locale/ru_RU/LC_MESSAGES/humanize.po", 
-    "humanize/number.py", 
-    "humanize/time.py", 
-    "python_qosf-1.1.7-py2.7.egg-info/PKG-INFO", 
-    "python_qosf-1.1.7-py2.7.egg-info/SOURCES.txt", 
-    "python_qosf-1.1.7-py2.7.egg-info/dependency_links.txt", 
-    "python_qosf-1.1.7-py2.7.egg-info/not-zip-safe", 
-    "python_qosf-1.1.7-py2.7.egg-info/requires.txt", 
-    "python_qosf-1.1.7-py2.7.egg-info/top_level.txt", 
+    "python_qosf-1.1.8-py2.7.egg-info/PKG-INFO", 
+    "python_qosf-1.1.8-py2.7.egg-info/SOURCES.txt", 
+    "python_qosf-1.1.8-py2.7.egg-info/dependency_links.txt", 
+    "python_qosf-1.1.8-py2.7.egg-info/not-zip-safe", 
+    "python_qosf-1.1.8-py2.7.egg-info/requires.txt", 
+    "python_qosf-1.1.8-py2.7.egg-info/top_level.txt", 
     "requests_oauthlib-0.6.2-py2.7.egg-info/PKG-INFO", 
     "requests_oauthlib-0.6.2-py2.7.egg-info/SOURCES.txt", 
     "requests_oauthlib-0.6.2-py2.7.egg-info/dependency_links.txt", 
